start

# Mozilla and Java properties files

The Translate Toolkit can manage Java .properties files with the prop2po and po2prop tool. As part of the Mozilla localisation process, the moz2po tool handles the properties files along with the other files. The tools can also handle Skype .lang files, and should handle Adobe Flex properties files as well.

## Features

- Fully manage Java escaping (Mozilla non-escaped form is also handled)
- Preserves the layout of the original source file in the translated version

## Not implemented

- Does not fold access keys together as done in the Mozilla DTD format.
- No specific style has been implemented for Adobe Flex files. Although they claim they are standard Java files, they also specify that the files are in UTF-8 encoding, which is different from Java properties.

## Examples

    editmenu.label = "Edit"
    saveas.label = "Save As"

## References

- Java Properties Class load method describes the properties format.
- http://java.sun.com/dtd/properties.dtd - alternate XML based property representation
- http://livedocs.adobe.com/flex/3/html/l10n_3.html - Description for Adobe Flex properties files